Crate bcx_model

Crate bcx_model 

Causal operation model types for BCX.

Structs

Admission
Admission decision for a prior intent.
CauseCapsule
Validated compact event capsule for causal parentage.
CauseCapsuleParts
Compact event capsule for causal parentage.
Checkpoint
Checkpoint statement for committed graph, state, or settlement evidence.
Contradiction
Contradiction between two distinct statements.
Delegation
Delegation from one subject to another under a capability reference.
Effect
Recorded effect for a prior intent.
Intent
Declared intent before execution.
Revocation
Revocation of a prior statement by an authority.

Enums

AdmissionResult
Admission decision produced before execution.
AssuranceLevel
Assurance level for a causal edge or effect claim.
CauseKind
Observable cause class for an operation.
EffectResult
Execution result recorded after an operation attempt.
OperationAction
High-level operation action.
RelationshipKind
Relationship between a BCX event and one of its parents.
StatementKind
BCX statement body kind.
TruthStatus
Truth status attached to explanation claims.