CauseCapsuleParts

Struct CauseCapsuleParts 

pub struct CauseCapsuleParts<'a> {
    pub event_id: EventId,
    pub parents: &'a [EventId],
    pub relationship: RelationshipKind,
    pub cause_kind: CauseKind,
    pub action: OperationAction,
    pub authority: Option<CapabilityRef>,
    pub policy_epoch: Option<PolicyEpoch>,
}
Compact event capsule for causal parentage.

Fields

event_id: EventId

Local event identifier.

parents: &'a [EventId]

Parent event identifiers.

The compact capsule uses the same RelationshipKind for every parent. Use separate capsules when parents need different relationship meanings.

relationship: RelationshipKind

Relationship used for every parent in this compact capsule.

cause_kind: CauseKind

Observable cause class.

action: OperationAction

Requested action.

authority: Option<CapabilityRef>

Optional authority reference.

policy_epoch: Option<PolicyEpoch>

Optional policy epoch reference.